@@ -28,8 +28,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Iterator, List, Union
+from typing import Generic, Iterator, List, TypeVar, Union
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import AlarmTypeType, HistoryItemTypeType, ScanByType, StateValueType
@@ -60,9 +61,19 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class DescribeAlarmHistoryPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
     """
 
@@ -76,16 +87,16 @@ class DescribeAlarmHistoryPaginator(Boto3Paginator):
         EndDate: Union[datetime, str] = None,
         ScanBy: ScanByType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeAlarmHistoryOutputTypeDef]:
+    ) -> _PageIterator[DescribeAlarmHistoryOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
         """
 
 
 class DescribeAlarmsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
     """
 
@@ -100,16 +111,16 @@ class DescribeAlarmsPaginator(Boto3Paginator):
         StateValue: StateValueType = None,
         ActionPrefix: str = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeAlarmsOutputTypeDef]:
+    ) -> _PageIterator[DescribeAlarmsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
         """
 
 
 class GetMetricDataPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
     """
 
@@ -122,31 +133,31 @@ class GetMetricDataPaginator(Boto3Paginator):
         ScanBy: ScanByType = None,
         LabelOptions: "LabelOptionsTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[GetMetricDataOutputTypeDef]:
+    ) -> _PageIterator[GetMetricDataOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
         """
 
 
 class ListDashboardsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
     """
 
     def paginate(
         self, *, DashboardNamePrefix: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDashboardsOutputTypeDef]:
+    ) -> _PageIterator[ListDashboardsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
         """
 
 
 class ListMetricsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
     """
 
@@ -158,8 +169,8 @@ class ListMetricsPaginator(Boto3Paginator):
         Dimensions: List["DimensionFilterTypeDef"] = None,
         RecentlyActive: Literal["PT3H"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListMetricsOutputTypeDef]:
+    ) -> _PageIterator[ListMetricsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.31/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.34/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
         """
